From bc92ca56ef6c51393d2782b7654eaa162dfc2e10 Mon Sep 17 00:00:00 2001
From: Aleksander Machniak <alec@alec.pl>
Date: Mon, 30 Jul 2012 07:20:56 -0400
Subject: [PATCH] Fixes after default->classic switch
---
program/include/rcube_message.php | 60 +++++++++++++++++++++++++++++++++++++++++++++++-------------
1 files changed, 47 insertions(+), 13 deletions(-)
diff --git a/program/include/rcube_message.php b/program/include/rcube_message.php
index 295b06e..9d36acf 100644
--- a/program/include/rcube_message.php
+++ b/program/include/rcube_message.php
@@ -17,9 +17,6 @@
+-----------------------------------------------------------------------+
| Author: Thomas Bruederli <roundcube@gmail.com> |
+-----------------------------------------------------------------------+
-
- $Id$
-
*/
@@ -33,9 +30,9 @@
class rcube_message
{
/**
- * Instace of rcmail.
+ * Instace of framework class.
*
- * @var rcmail
+ * @var rcube
*/
private $app;
@@ -166,11 +163,13 @@
/**
* Get content of a specific part of this message
*
* @param string $mime_id Part MIME-ID
* @param resource $fp File pointer to save the message part
* @return string Part content
*/
- public function get_part_content($mime_id, $fp=NULL)
+ public function get_part_content($mime_id, $fp = null, $skip_charset_conv = false)
{
if ($part = $this->mime_parts[$mime_id]) {
// stored in message structure (winmail/inline-uuencode)
@@ -181,7 +180,7 @@
return $fp ? true : $part->body;
}
// get from IMAP
- return $this->storage->get_message_part($this->uid, $mime_id, $part, NULL, $fp);
+ return $this->storage->get_message_part($this->uid, $mime_id, $part, NULL, $fp, $skip_charset_conv);
} else
return null;
}
@@ -274,6 +273,32 @@
$part = null;
return null;
+ }
+
+
+ /**
+ * Checks if part of the message is an attachment (or part of it)
+ *
+ * @param rcube_message_part $part Message part
+ *
+ * @return bool True if the part is an attachment part
+ */
+ public function is_attachment($part)
+ {
+ foreach ($this->attachments as $att_part) {
+ if ($att_part->mime_id == $part->mime_id) {
+ return true;
+ }
+
+ // check if the part is a subpart of another attachment part (message/rfc822)
+ if ($att_part->mimetype == 'message/rfc822') {
+ if (in_array($part, (array)$att_part->parts)) {
+ return true;
+ }
+ }
+ }
+
+ return false;
}
@@ -653,23 +678,29 @@
$parts = array();
// FIXME: line length is max.65?
- $uu_regexp = '/begin [0-7]{3,4} ([^\n]+)\n(([\x21-\x7E]{0,65}\n)+)`\nend/s';
+ $uu_regexp = '/begin [0-7]{3,4} ([^\n]+)\n/s';
if (preg_match_all($uu_regexp, $part->body, $matches, PREG_SET_ORDER)) {
- // remove attachments bodies from the message body
- $part->body = preg_replace($uu_regexp, '', $part->body);
// update message content-type
$part->ctype_primary = 'multipart';
$part->ctype_secondary = 'mixed';
$part->mimetype = $part->ctype_primary . '/' . $part->ctype_secondary;
+ $uu_endstring = "`\nend\n";
// add attachments to the structure
foreach ($matches as $pid => $att) {
+ $startpos = strpos($part->body, $att[1]) + strlen($att[1]) + 1; // "\n"
+ $endpos = strpos($part->body, $uu_endstring);
+ $filebody = substr($part->body, $startpos, $endpos-$startpos);
+
+ // remove attachments bodies from the message body
+ $part->body = substr_replace($part->body, "", $startpos, $endpos+strlen($uu_endstring)-$startpos);
+
$uupart = new rcube_message_part;
$uupart->filename = trim($att[1]);
$uupart->encoding = 'stream';
- $uupart->body = convert_uudecode($att[2]);
+ $uupart->body = convert_uudecode($filebody);
$uupart->size = strlen($uupart->body);
$uupart->mime_id = 'uu.' . $part->mime_id . '.' . $pid;
@@ -680,6 +711,9 @@
$parts[] = $uupart;
unset($matches[$pid]);
}
+
+ // remove attachments bodies from the message body
+ $part->body = preg_replace($uu_regexp, '', $part->body);
}
return $parts;
@@ -166,11 +163,13 @@
* Get content of a specific part of this message
*
- * @param string $mime_id Part MIME-ID
- * @param resource $fp File pointer to save the message part
+ * @param string $mime_id Part MIME-ID
+ * @param resource $fp File pointer to save the message part
+ * @param boolean $skip_charset_conv Disables charset conversion
+ *
* @return string Part content
*/
--
Gitblit v1.9.1